@@ -1,7 +1,7 @@
 use pyo3::prelude::*;
 
 use crate::font::Font;
-use imagetext::drawing::prelude::*;
+use imagetext::prelude::*;
 
 #[pyfunction]
 pub fn text_size(text: &str, size: f32, font: &Font) -> (i32, i32) {
@@ -23,11 +23,6 @@ pub fn text_size_multiline(
     )
 }
 
-#[pyfunction]
-pub fn split_on_space(text: &str) -> Vec<&str> {
-    imagetext::wrap::split_on_space(text)
-}
-
 #[pyfunction]
 pub fn word_wrap(text: &str, width: i32, size: f32, font: &Font) -> Vec<String> {
     imagetext::wrap::word_wrap(text, width, &font.superfont(), scale(size))
